AdapterInput

Struct AdapterInput 

pub struct AdapterInput<S> {
    pub encoded: EncodedScene,
    pub encoded_seq: u64,
    pub state: S,
    pub state_seq: u64,
}
Input consumed by one adapter-loop step.

Fields

encoded: EncodedScene

Latest content-rate encoded Scene.

encoded_seq: u64

Sequence of the encoded Scene.

state: S

Freshest device-local state available for this step.

state_seq: u64

Modeled tick sequence for state.

Implementations

Source

impl<S> AdapterInput<S>

pub fn new( encoded: EncodedScene, encoded_seq: u64, state: S, state_seq: u64, ) -> Self

Builds an input from an encoded Scene and state.

pub fn from_shared_scene( scene: Rc<Expr>, encoded_seq: u64, state: S, state_seq: u64, ) -> Self

Builds an input from a shared encoded Scene pointer.