pub struct Frame {
pub out: Rc<Expr>,
pub dropped: u32,
pub stale: bool,
pub seq: u64,
pub encoded_seq: u64,
}Expand description
Output of one adapter-loop step.
Fields
out: Rc<Expr>Local adapter output.
dropped: u32Number of offered state updates coalesced before this step.
stale: boolWhether the newest state exceeded the stale window.
seq: u64Modeled frame sequence.
encoded_seq: u64Sequence of the encoded Scene used for this step.