Module split
sim_
lib_
view_
device
0.1.1
Module split
Module Items
Structs
Functions
In crate sim_
lib_
view_
device
sim_lib_view_device
Module
split
Content-rate encoding plus device-rate local adaptation.
Structs

Split
Runs one content encode and then many local adaptations.
Split
Run
Result of a split run.
Functions

drive
Adapts an already encoded Scene for many device states.