pub struct AdapterInput<S> {
pub encoded: EncodedScene,
pub encoded_seq: u64,
pub state: S,
pub state_seq: u64,
}Expand description
Input consumed by one adapter-loop step.
Fields
encoded: EncodedSceneLatest content-rate encoded Scene.
encoded_seq: u64Sequence of the encoded Scene.
state: SFreshest device-local state available for this step.
state_seq: u64Modeled tick sequence for state.
Implementations
Sourceimpl<S> AdapterInput<S>
impl<S> AdapterInput<S>
Sourcepub fn new(
encoded: EncodedScene,
encoded_seq: u64,
state: S,
state_seq: u64,
) -> Self
pub fn new( encoded: EncodedScene, encoded_seq: u64, state: S, state_seq: u64, ) -> Self
Builds an input from an encoded Scene and state.
Builds an input from a shared encoded Scene pointer.